/*

  Azulejos - A decorative, seamless tile pigment generator

  Based on trigonometrical functions repeated on the z plane, along x and y
  axis, using a repeating-warp technique by Tek.

  --
  Jaime Vives Piqueres, Feb. 2004


*/
#version 3.5;

#include "colors.inc"
#include "functions.inc"

// defaults
#ifndef (TILE_USE_WARPS) #declare TILE_USE_WARPS=1; #end
#ifndef (TILE_WARP_SIZE) #declare TILE_WARP_SIZE=1; #end
#ifndef (TILE_WARP_ANGLE) #declare TILE_WARP_ANGLE=45; #end

// *** Seamless Tile Pigment ***
//
// params:
//   tf = base function 
//   bc = background color
//   cs = separation color
//   ac = array of base colors
//   ca = color amount
//   sa = separation amount
//   ct = color_map type : 0=solid, 1=half-gradient, 2=gradient
//
// Returns: pattern and color_map for a pigment
//
// Usage: 
//   pigment{ p_tile(...) [OTHER_PIGMENT_MODIFIFERS] }
//
#macro p_tile(tf,bc,cs,ac,ca,sa,pm)

#local nc=dimension_size(ac,1);   // number of colors
#local ic=0;

 function{tf(x,y,z)}

 color_map{
 #switch (pm)
 // solid
 #case (0)
  #while (ic<nc)
   [ic/nc ac[ic]]
   [(ic+ca)/nc ac[ic]]
   [(ic+ca)/nc cs]
   [(ic+ca+sa)/nc cs]
   [(ic+ca+sa)/nc bc]
   [(ic+1-sa)/nc bc]
   [(ic+1-sa)/nc cs]
   [(ic+1)/nc cs]
   #local ic=ic+1;
  #end
  #break
 // half-gradient
 #case (1)
  #while (ic<nc)
   [ic/nc ac[ic]]
   [(ic+ca)/nc bc]
   [(ic+ca)/nc cs]
   [(ic+ca+sa)/nc cs]
   [(ic+ca+sa)/nc bc]
   [(ic+1-sa)/nc bc]
   [(ic+1-sa)/nc cs]
   [(ic+1)/nc cs]
   #local ic=ic+1;
  #end
  #break
 // gradient
 #case (2)
  #while (ic<nc)
   [ic/nc ac[ic]]
   [(ic+ca)/nc bc]
   [(ic+ca+sa)/nc ac[ic]]
   [(ic+1-sa)/nc bc]
   [(ic+1-sa)/nc cs]
   [(ic+1)/nc cs]
   #local ic=ic+1;
  #end
  #break
 #else
  #error "p_tile() error : Wrong color_map type"   
  #break
 #end
 }

 // use rotating warps for the semaless effect (Thanks Tek!)
 #local nCount = 0;
 #while ( nCount < 360/TILE_WARP_ANGLE )
   rotate TILE_WARP_ANGLE*z
   warp { repeat TILE_WARP_SIZE*x flip x}
   warp { repeat TILE_WARP_SIZE*y flip y}
   #local nCount = nCount + 1;
 #end

#end


// *** PREDEFINED VALUES AND OBJECTS ***

// basic colors
#declare c_tile_background=White; 
#declare c_tile_separator=Black;
#declare c_tile_blue=NavyBlue*.5+SteelBlue*.5;
#declare c_tile_yellow=Orange*.2+Yellow*.4+White*.4;
#declare c_tile_orange=OrangeRed*.6+White*.2;
#declare c_tile_green=SeaGreen*.4+White*.2+Green*.1+Blue*.1;

// basic function for tests
#declare f_test=function{sin(x)+cos(y)}

// basic tile object for tests
#declare basic_tile=
superellipsoid{<.1,.05> rotate 90*x scale .5}




