/*

  The Kitchen - Jaime Vives Piqueres 2004-2005

  Entry for the POVCOMP 2004

  Main scene file (but don't render it directly: see README file)

*/

// *** control center ***
#declare camera_select=1; // select camera (see EOF)
#declare use_curtains =1; // hanging curtains
#declare use_bottles  =1; // glass bottles
#declare use_glasses  =1; // glasses
#declare use_waterb   =1; // waterb bottle
#declare use_plates   =1; // plates
#declare use_oranges  =1; // oranges & bowl
#declare use_apples   =1; // apples, banana & bowl
#declare use_mwaver   =1; // microwaves oven
#declare use_cboard   =1; // cutting board
#declare use_cleaning =1; // cleanning products
#declare use_sinkobj  =1; // sink
#declare use_drape    =1; // yellow drape
#declare use_misc     =1; // forsk, spoons, papers roll, shocket & cable, ...
#declare use_kitchen  =1; // kitchen
#declare use_klight   =1; // kitchen light 
#declare use_fridge   =1; // refrigerator
#declare use_table    =1; // circular table with tablecloth
#declare use_chairs   =1; // chairs
#declare use_cereals  =1; // cereal box and bowl with milk
#declare use_wclock   =1; // wall clock
#declare use_tray     =1; // wooden tray
#declare use_ktowel   =1; // hanging towel
#declare use_plants   =1; // flowers plant
#declare use_furniture=1; // furniture: counter-top, cabinets, shelves,...
#declare use_ceillamp =0; // ceil fluorescent panel lamp
#declare use_corrlight=0; // idem on the corridor
#declare use_daylight =1; // daylight from the window


// *** comon data ***
#declare room_height=250;
#declare room_width=300;
#declare room_length=400;
#declare wall_width=20;
#declare win_width=75;
#declare win_height=90;
#declare win_pos=<0,165,55-7.5>;
#declare door_width=100;
#declare door_height=190;
#declare floor_height=300;


// *** global settings ***
global_settings{
 max_trace_level 9
 assumed_gamma 1.0
 #if (use_radiosity)
  #include "i_rad.inc"
 #end
 #if (use_photons)
  photons{
   spacing .025
   autostop 0
  }
 #end
}
#default{
 texture{
  finish{ambient 0}  // before any finish definition
 }
}


// *** STANDARD INCLUDES ***
#include "colors.inc"  
#include "textures.inc"  
#include "metals.inc"
#include "woods.inc"
#include "stones.inc"
#include "glass.inc"
#include "functions.inc"


// *** CUSTOM GENERIC INCLUDES ***
// tile pigment gerator
#include "i_azulejos.inc"
// Lightsys & CIE
#include "CIE.inc"
#include "lightsys.inc"
#include "lightsys_constants.inc"
#declare Lightsys_Brightness=11;


// *** CUSTOM TEXTURES ***
#include "rspd_jvp.inc"
#include "rspd_aster.inc"
// change color system to convert pigment samples:
CIE_ColorSystemWhitepoint(CIE_ColSys,Illuminant_D50) 
#include "i_textures.inc"
// restore color system for the lights:
CIE_ColorSystem(sRGB_ColSys) 


// *** CUSTOM GENERIC INCLUDES ***
#include "i_rbox.inc"		// rounded box
#include "i_vase.inc"		// vases
#include "i_bowl1.inc"		// bowl
#include "i_spoon.inc"		// spoon
#include "i_fork.inc"		// fork
#include "i_knife1.inc"		// knife
#include "i_kpot.inc"		// kitchen pot
#include "i_spicespot.inc"	// spices jar


// *** ROOM ***
#include "i_room.inc"
object{kitchen_room
 translate floor_height*y
}
plane{y,floor_height hollow
 texture{t_floor}
}


// *** FLUORESCENT LAMP ***
#include "i_fluorlamp.inc"
// on this room
#if (use_ceillamp)
object{fluor_lamp translate < 0,248, 0> translate floor_height*y}
#else
object{fluor_lamp_off translate <0,248,0> translate floor_height*y}
#end
// on the corridor
#if (use_corrlight)
object{fluor_lamp
 translate <0,248,-room_length>
 translate floor_height*y
}
#else
object{fluor_lamp_off
 translate <0,248,-room_length>
 translate floor_height*y
}
#end


// *** WINDOW ***
#if (use_window)
#include "i_winhandle.inc"
#include "i_window.inc"
/*
union{
 object{
  Window_01(win_width,win_height,wall_width*.25,t_white_paint,t_wglass,Polished_Chrome,0,0,21,0)
  scale <1,1,1.5>
 }
 object{window_handle scale 39 rotate 180*y translate <1,0,-1>}
*/
// finally didn't use the window, but a with plane:
box{-.5,.5 scale <win_width,win_height,.1> no_shadow hollow
 texture{t_white_paint}
 rotate 90*y
 translate <room_width*.5+wall_width*.75,win_pos.y,win_pos.z>
 translate floor_height*y
}
#end


// *** CURTAINS ***
#if (use_curtains)
#declare i_curtain=
interior{
 media{scattering{1,1}}
 media{scattering{1,1}}
 media{scattering{1,1}}
}
#include "i_curtain.inc"
object{curtain 
  hollow
  scale <50,50,20>
  #if (use_radiosity<2)
  interior{i_curtain}
  #end
  rotate 90*y
  translate <room_width*.5-2,win_pos.y,win_pos.z-35>
  translate <-1.5,floor_height,0>
}
object{curtain 
  hollow rotate 180*y
  scale <50,50,20>
  #if (use_radiosity<2)
  interior{i_curtain}
  #end
  rotate 90*y
  translate <room_width*.5-2,win_pos.y,win_pos.z+35>
  translate <-1.5,floor_height,0>
}
// wood tube and rings
union{
  cylinder{<-51,0,0>,<51,0,0>,1}
  cylinder{<-50,0,0>,<-50,0,10>,1}
  cylinder{<50,0,0>,<50,0,10>,1}
  sphere{0,2 translate -52*x}
  sphere{0,2 translate  52*x}
  torus{2,.4 rotate 90*z translate <45,-1.0,0>}
  torus{2,.4 rotate 90*z translate <42,-1.0,0>}
  torus{2,.4 rotate 90*z translate <37,-1.0,0>}
  torus{2,.4 rotate 90*z translate <29,-1.0,0>}
  torus{2,.4 rotate 90*z translate <25,-1.0,0>}
  torus{2,.4 rotate 90*z translate <-44,-1.0,0>}
  torus{2,.4 rotate 90*z translate <-41,-1.0,0>}
  torus{2,.4 rotate 90*z translate <-32,-1.0,0>}
  torus{2,.4 rotate 90*z translate <-29,-1.0,0>}
  torus{2,.4 rotate 90*z translate <-26,-1.0,0>}
  texture{t_wood_furn rotate 90*y}
  rotate 90*y
  translate <room_width*.5-2,win_pos.y+51.5,win_pos.z>
  translate <-1.5,floor_height,0>
}
#end


// *** FURNTURE ***
#if (use_furniture)
// counter top with sink and cabinets
#include "i_furniture.inc"
object{sink_bench
 translate <room_width*.5,0,win_pos.z>
 translate floor_height*y
}
#end


// *** OBJECTS IN THE SINK ***
#if (use_sinkobj)
#declare t_plate2=t_white_plastic
#include "i_plate2.inc"
union{
 object{plate2 scale 10 rotate 65*z}
 object{plate2 scale 10 rotate 70*z translate 5*x}
 object{plate2 scale 10 rotate 80*z translate 9*x}
 object{olla1 scale 8 rotate 10*x translate <-12,5,4.5>}
 object{bowl1(t_ceramic) scale 6 rotate -20*x translate <-10,1,-8>}
 translate <room_width*.5-25,85,win_pos.z+25>
 translate floor_height*y
}
#end


// *** MICROWAVER ***
#if (use_mwaver)
#include "i_microwave.inc"
object{jvp_microwave
 scale .8
 translate <110,104,room_length*.5-21>
 translate floor_height*y
}
#end


// *** KITCHEN ***
#if (use_kitchen)
#declare r_coc=seed(6238);
#include "i_kitchen.inc"
object{cocina
 translate <7.5,49,room_length*.5-36>
 translate floor_height*y
}
object{kitchen_extractor
 translate <7.5,176,room_length*.5-40>
 translate floor_height*y
}
#end


// *** KITCHENWARE ***
#if (use_kitchen)
// frying pans
#include "i_fpan.inc"
object{sarten1 scale 9 rotate 110*y
 translate <25,99,room_length*.5-36-15>
 translate floor_height*y
}
object{sarten1 scale 8 rotate <-89,-91,0>
 translate <room_width*.5-5,124.5,-56>
 translate floor_height*y
}
object{sarten1 scale 7 rotate <-89,-96,0>
 translate <room_width*.5-5,128,-76>
 translate floor_height*y
}
object{sarten1 scale 6 rotate <-89,-88,0>
 translate <room_width*.5-5,131.5,-93>
 translate floor_height*y
}
object{olla1 scale <16,14,16> rotate 80*y
 translate <-14,104.5,room_length*.5-36+15>
 translate floor_height*y
}
// coffe machine
#include "i_coffem.inc"
object{cafetera scale <3,3.5,3>*1.1 rotate -93*y
 translate <26.5,93.8,room_length*.5-36+19>
 translate floor_height*y
}
// kitchen accesories
#include "i_ladle.inc"
object{cazo scale 4 rotate 180*y rotate -15*x
 translate <20,139.7,room_length*.5-7>
 translate floor_height*y
}
#include "i_skimmer.inc"
object{paleta scale 4 rotate 180*y rotate -15*x
 translate <15,139.7,room_length*.5-7>
 translate floor_height*y
}
#end


// *** SPICES ***
#declare r_spc=seed(787);
object{spices_pot(t_red_plastic,t_spices_label,t_wb_pet,pigment{OrangeRed},t_wb_pet,t_wb_pet)
 scale 2
 rotate 360*rand(r_spc)*y
 translate <8+15,187,room_length*.5-52.5>
 translate floor_height*y
}
object{spices_pot(t_green_plastic,t_spices_label,t_wb_pet,pigment{ForestGreen},pigment{ForestGreen},t_wb_pet)
 scale 2
 rotate 360*rand(r_spc)*y
 translate <8-14,187,room_length*.5-52>
 translate floor_height*y
}
object{spices_pot(t_orange_plastic,t_spices_label,t_wb_pet,pigment{Gold},pigment{Gold},pigment{Gold})
 scale 2
 rotate 360*rand(r_spc)*y
 translate <8+15+6,187,room_length*.5-53>
 translate floor_height*y
}
object{spices_pot(t_blue_plastic,t_spices_label,t_wb_pet,pigment{Flesh},t_wb_pet,t_wb_pet)
 scale 2
 rotate 360*rand(r_spc)*y
 translate <8-14-7,187,room_length*.5-52.5>
 translate floor_height*y
}
object{spices_pot(t_red_plastic,t_spices_label,t_wb_pet,pigment{DarkTan},pigment{DarkTan},t_wb_pet)
 scale 2
 rotate 360*rand(r_spc)*y
 translate <8+15+6+5,187,room_length*.5-52>
 translate floor_height*y
}


// *** FRIDGE ***
#if (use_fridge)
#include "i_fridge.inc"
object{fridge
 translate <room_width*.5-33,.1,-100-35>
 translate floor_height*y
}
#end


// *** KITCHEN TABLE ***
#if (use_table)
#include "i_tablecloth.inc"
union{
 union{
  cylinder{<0,-1,0>,<0,1,0>,47.5}
  cylinder{<0,-6,0>,<0,-1,0>,45}
  cone{<0,-1,0>,3,<0,-80,0>,1 translate -45*z rotate 0*y}
  cone{<0,-1,0>,3,<0,-80,0>,1 translate -45*z rotate 90*y}
  cone{<0,-1,0>,3,<0,-80,0>,1 translate -45*z rotate 180*y}
  cone{<0,-1,0>,3,<0,-80,0>,1 translate -45*z rotate 270*y}
  texture{t_white_plastic}
 }
 object{tablecloth scale 100 translate -38*y}
 rotate 193*y
 translate <-room_width*.5+60+20,80,-20>
 translate floor_height*y
}
#end


// *** CHAIRS ***
#if (use_chairs)
#declare t_chair_seat=t_wood_chair
#declare t_chair_legs=texture{t_chair_seat rotate 90*x}
#include "i_chair.inc"
object{chair scale <20,25,20> rotate -80*y
 translate <-room_width*.5+60+70+20,40,-20-10>
 translate floor_height*y
}
object{chair scale <20,25,20> rotate -140*y
 translate <-room_width*.5+60+20+20,40,-20+70>
 translate floor_height*y
}
#end


// *** BOTTLES ***
#if (use_bottles)
#include "meshlath.inc"
#include "i_bottles.inc"
object{bottle1 
 translate <72,91.51,room_length*.5-6>
 translate floor_height*y
}
object{bottle2
 translate <81,91.51,room_length*.5-9>
 translate floor_height*y
}
#end


// *** MISC KITCHEN OBJECTS ***
#if (use_misc)
// wooden fork and spoon on a pot
#include "i_bowl3.inc"
union{
 object{bowl3(t_green_plastic) scale 6}
 object{fork(T_Wood1) scale 2.5 rotate -75*x rotate -40*y translate <-6,11,3>}
 object{spoon(T_Wood1) scale 2.5 rotate -70*x rotate 55*y translate <5,11,-1>}
 translate <61,96.51,room_length*.5-8>
 translate floor_height*y
}
// metal forks and spoons on a pot
union{
 object{bowl3(t_white_plastic) scale 6}
 object{fork(t_chrome) scale 2 rotate -85*x translate <2,8,3>}
 object{spoon(t_chrome) scale 2 rotate -75*x rotate 65*y translate <3.5,8,-1>}
 object{fork(t_chrome) scale 2 rotate -75*x rotate -40*y translate <-3,8,0>}
 object{spoon(t_chrome) scale 2 rotate -75*x rotate -85*y translate <-6,8,1>}
 object{knife1 scale 1 rotate -80*x rotate 170*y translate <-1,5,-1>}
 object{knife1 scale 1 rotate -120*x rotate 0*y translate <-1.5,5,-4>}
 translate <room_width*.5-20,96.51,room_length*.5-69>
 translate floor_height*y

}
// kitchen paper
#include "i_kpaper.inc"
union{
 object{kpaper scale <6,7,6> rotate -120*y translate 13.5*y}
 union{
  cylinder{<0,0,0>,<0,2,0>,7}
  cylinder{<0,0,0>,<0,28,0>,1.5}
  texture{T_Wood1 rotate 90*x}
 }
 translate <82,91.52,room_length*.5-24>
 translate floor_height*y
}
// *** SHOCKET & CABLE ***
#include "i_shocket.inc"
#include "i_mcable.inc"
union{
 object{shocket_sp rotate 90*y}
 object{mcable(t_black_plastic) scale 1.3 rotate 180*y translate -3.5*y}
 translate <room_width*.5-1.5,128,room_length*.5-11>
 translate floor_height*y
}
#end


// *** GLASSES ***
#if (use_glasses)
// clear drinking glasses
#include "i_glass.inc"
union{
 object{glass1 rotate 180*x translate <room_width*.5-10,91.51+12.5,room_length*.5-79>}
 object{glass1 rotate 180*x translate <room_width*.5-10.1,91.51+12.5,room_length*.5-89>}
 object{glass1 rotate 180*x translate <room_width*.5-10.1,91.51+12.5,room_length*.5-99>}
 object{glass1 rotate 180*x translate <room_width*.5-10.1,91.51+12.5*2,room_length*.5-84>}
 object{glass1 rotate 180*x translate <room_width*.5-10.1,91.51+12.5*2,room_length*.5-94>}
 object{glass1 rotate 180*x translate <room_width*.5-19,91.51+12.5,room_length*.5-85>}
 translate floor_height*y
}
// coffe mug
#include "i_coffemug.inc"
object{coffe_mug(t_orange_plastic) scale 4
 translate <room_width*.5-25,91.5,room_length*.5-95>
 translate floor_height*y
}
// glass on the table with water
#if (use_table)
union{
 object{glass1}
 object{glass_content 
  material{m_water}
  scale .999999 
 }
 #if (use_photons)
 photons{
  target
  refraction on
  reflection off
  collect off
 }
 #end
 translate <-room_width*.5+58+10,81.2,-20-22-1>
 translate floor_height*y
}
#end
#end


// *** PLATES ***
#if (use_plates)
// make som piles
#declare r_plt=seed(6757);
#include "i_plates.inc"
#declare ips=.7;
#declare ppile1=
union{
 object{plato(1,seed(7)) rotate <-1+2*rand(r_plt),360*rand(r_plt),0>}
 object{plato(1,seed(7)) rotate <-1+2*rand(r_plt),360*rand(r_plt),0> translate ips*y}
 object{plato(1,seed(7)) rotate <-1+2*rand(r_plt),360*rand(r_plt),0> translate ips*2*y}
 object{plato(1,seed(7)) rotate <-1+2*rand(r_plt),360*rand(r_plt),0> translate ips*3*y}
 object{plato(1,seed(7)) rotate <-1+2*rand(r_plt),360*rand(r_plt),0> translate ips*4*y}
 object{plato(1,seed(7)) rotate <-1+2*rand(r_plt),360*rand(r_plt),0> translate ips*5*y}
}
#declare tmph=ips;
#declare ips=.6;
#declare ppile2=
union{
 object{plato(.75,seed(7)) rotate <-1+2*rand(r_plt),360*rand(r_plt),0>}
 object{plato(.75,seed(7)) rotate <-1+2*rand(r_plt),360*rand(r_plt),0> translate ips*y}
 object{plato(.75,seed(7)) rotate <-1+2*rand(r_plt),360*rand(r_plt),0> translate ips*2*y}
 object{plato(.75,seed(7)) rotate <-1+2*rand(r_plt),360*rand(r_plt),0> translate ips*3*y}
 object{plato(.75,seed(7)) rotate <-1+2*rand(r_plt),360*rand(r_plt),0> translate ips*4*y}
 object{plato(.75,seed(7)) rotate <-1+2*rand(r_plt),360*rand(r_plt),0> translate ips*5*y}
}
union{
 object{ppile1}
 object{ppile2 translate tmph*6*y}
 scale <1,1.5,1>
 translate <room_width*.5-14,161.5,-55>
 translate floor_height*y
}
// more object on the shelves
// vegetables jars
object{spices_pot(t_pot_tap1,t_wb_pet,t_wb_pet,t_garbanzos,t_wb_pet,t_wb_pet)
 scale <5,4,5>
 translate <room_width*.5-15,167.51,-73>
 translate floor_height*y
}
object{spices_pot(t_pot_tap1,t_wb_pet,t_wb_pet,t_lentejas,t_lentejas,t_wb_pet)
 scale <5,4,5>
 translate <room_width*.5-13,167.51,-84>
 translate floor_height*y
}
// simple teapot
#include "i_teapot.inc"
object{tetera scale 7 rotate 70*y
 translate <room_width*.5-13,161.51,-33>
 translate floor_height*y
}
// stylized vase on 4 sizes
#declare base_vase=
object{rand_vase2(20,25,4,seed(25692))
  texture{t_blue_vase}
}
union{
 object{base_vase scale .8
  translate <1,0,-20>
 }
 object{base_vase scale .7
  translate <0,0,-2>
 }
 object{base_vase scale .6
  translate <1,0,15>
 } 
 object{base_vase scale .5
  translate <2,0,30>
 } 
 translate <room_width*.5-15,191.51,-63>
 translate floor_height*y
}

#end


// *** ORANGES BOWL ***
#if (use_oranges)
#include "i_orange.inc"
#declare r_orng=seed(6537);
union{
 object{bowl1(texture{T_Stone21}) scale 10}
 #declare iorng=0;
 #declare norng=7;
 #while (iorng<norng)
  object{orange rotate 360*rand(r_orng)
   translate -int(8*rand(r_orng))*z
   rotate 90*rand(r_orng)*x
   rotate 360*rand(r_orng)*y
   translate 6*y
  }
  #declare iorng=iorng+1;
 #end
 translate <109,104+11.1,room_length*.5-22>
 translate floor_height*y
}
object{orange rotate 360*rand(r_orng)
 translate <-room_width*.5+58+18+1,81.1+3.7,-20-22-5> // on the table
 translate floor_height*y
}
#end


// *** DRAPE ***
#if (use_drape)
#declare drape=
mesh{
#include "i_nappe.msh"
 texture{pigment{Yellow*.4+Orange*.4+Gray10}
  #if (use_normals)
  normal{granite scale .1}
  #end
  finish{diffuse 1}
 }
}
object{drape translate -.8*y scale 40
 rotate 45*y
 translate <room_width*.5-17,91.51,1>
 translate floor_height*y
}
#end


// *** WALL CLOCK ***
#if (use_wclock)
#declare t_wcboard=
texture{
 pigment{image_map{png "im_clock"} translate -.5 scale 16}
 #if (use_textures)
 finish{Glossy diffuse .9}
 #end
}
#include "i_wallclock.inc"
object{kitchen_clock
 rotate 5*x
 translate <8,191.5,room_length*.5-52.5>
 translate floor_height*y
}
#end


// *** WOODBOARD & KNIFE ***
#if (use_cboard)
#include "i_woodboard.inc"
#include "i_tomato.inc"
#include "i_tomatoh.inc"
union{
 object{woodboard scale 12 rotate -4*y translate 1*y}
 object{knife1 scale 1.5 rotate -13*x rotate 135*y translate <-11,2.1,2>}
 object{half_tomato scale 3.5 rotate 40*z rotate -90*y  translate <0,2.5,7>}
 object{tomato scale 3 rotate 30*y translate <2,2.4,-1>}
 object{tomato scale 3.5 rotate 80*y translate <-3,2.5,-12>}
 translate <room_width*.5-20,91.51,-58>
 translate floor_height*y
}
#end


// *** CLEANING PRODUCTS ***
#if (use_cleaning)
// on the counter-top
#include "i_cleaning1.inc"
object{cleaning1 scale 8 rotate -8*y
 translate <room_width*.5-43,41.51,win_pos.z+32>
 translate floor_height*y
}
// on the open cabinet:
#include "i_cleaning2.inc"
object{mr_pover scale 6.5 rotate 208*y
 translate <room_width*.5-25,91.51+9,-11>
 translate floor_height*y
}
#include "i_pots.inc"
object{
 bote_spray 
 rotate -115*y
 translate <room_width*.5-43,5.51,win_pos.z+35>
 translate floor_height*y
}
object{
 bote_vap
 scale <1.1,1.5,1.1>
 rotate 90*y
 translate <room_width*.5-45,5.51,win_pos.z+20>
 translate floor_height*y
}
#end


// *** PLANTS ***
#if (use_plants)
#declare r_p4=seed(937);
#include "i_plants.inc"
union{
 union{
  object{hanging_plant3(8,32,16,t_leaf4,r_p4)
   rotate 360*rand(r_p4)*y
   translate 10*y
  }
  object{pot2}
  scale .6
  translate .3*y
 }
 #if (use_plates)
 object{plato(.7,seed(7))}
 #end
 translate <room_width*.5-19,91.51,-23>
 translate floor_height*y
}
#end


// *** WATER BOTTLE ***
#if (use_waterb)
#include "i_waterbottle.inc"
object{waterbottle scale 8
 #if (use_glass)
 interior{I_Glass ior 1.2}
 #end
 #if (use_photons)
 photons{
  target
  refraction on
  reflection off
  collect off
 }
 #end
 translate <-room_width*.5+58+18+4,81.1+13.8,-20-22+2> // on the table
 translate floor_height*y
}
#end


// *** BANDEJA ***
#if (use_tray)
#declare t_ktray=
texture{T_Wood26 rotate 90*y}
#include "i_ktray.inc"
object{ktray scale 12 rotate <86,-90,0>
 translate <room_width*.5-3,91.51+12,149>
 translate floor_height*y
}
#end


// *** CEREALS ***
#if (use_table)
#if (use_cereals)
#include "i_cereals.inc"
#include "i_cerealbox.inc"
object{cerealbox scale <-1,1,1> scale 8 rotate 168*y
 translate <-room_width*.5+75+20+4,92,-30>
 translate floor_height*y
}
union{
 object{bowl1(texture{t_blue_plastic}) scale <7,6,7>}
 intersection{
  sphere{0,6}
  plane{y,0}
  hollow
  texture{t_milk}
  #if (use_textures)
  interior{
   ior 1.3
   media{
    absorption 10
    emission 1
    scattering{1,10}
   }
  }
  #end
  translate 4*y
 }
 object{pov_cereals
  translate 4*y
 }
 translate <-room_width*.5+58+20+10,81.2,-20-22-10>
 translate floor_height*y
}
object{spoon(t_chrome) scale 1.5 rotate -8*x
 rotate -120*y
 translate <-room_width*.5+65+27,82.4,-20-41>
 translate floor_height*y
}
#end
#end


// *** APPLES & BANANA ON THE TABLE ***
#if (use_apples)
#declare t_bowl2=t_white_plastic
#include "i_apples_tex.inc"
#include "i_bowl2.inc"
#include "i_apple1.inc"  
#include "i_apple2.inc"  
#include "i_banana.inc"  
union{
 object{bowl2 scale <10,8,10>
 }
 union{
  object{manzana1(seed(11),t_apple,3) rotate 7}
  object{manzana2(seed(12),t_apple,3) rotate 24 translate <-4,-3,-4>}
  object{manzana1(seed(13),t_apple,3) rotate 54 translate <-4,-3,-4> rotate 60*y}
  object{manzana2(seed(14),t_apple,3) rotate 94 translate <-4,-3,-4> rotate 60*2*y}
  object{manzana1(seed(15),t_apple,3) rotate 4 translate <-4,-3,-4> rotate 60*3*y}
  object{manzana2(seed(16),t_apple,3) rotate 124 translate <-4,-3,-4> rotate 60*4*y}
  object{manzana1(seed(17),t_apple,3) rotate 244 translate <-4,-3,-4> rotate 60*5*y}
  translate 1*y
 }
 object{platano scale 1.5 rotate 90*z rotate -90*y translate <0,1.5,5> rotate -35*y}
 translate <-room_width*.5+60+20,81.5+8.5,-20>
 translate floor_height*y
}
#end


// *** KITCHEN TOWEL ON THE WALL ***
#if (use_ktowel)
// hanging towel
#declare i_towel=
interior{
 media{scattering{1,1}}
 media{scattering{1,1}}
 media{scattering{1,1}}
}
#include "i_ktowel.inc"
object{ktowel hollow
 scale <1,1,-1> scale 15 rotate 90*y
 #if (use_radiosity<2)
  interior{i_towel}
 #end
 translate <room_width*.5-.5,152,win_pos.z+79>
 translate floor_height*y
}
// wall hook
union{
 superellipsoid{<.1,.1> scale .5 rotate <90,90,0> scale <.2,2,25>}
 sphere{0,1 scale <2,.5,.5> rotate -30*z translate <-.1,0,0>}
 sphere{0,1 scale <2,.5,.5> rotate -30*z translate <-.1,0,-7>}
 sphere{0,1 scale <2,.5,.5> rotate -30*z translate <-.1,0,7>}
 texture{t_chrome}
 translate <room_width*.5-.15,165,win_pos.z+73>
 translate floor_height*y
}
#end


// *** CANS ***
#include "i_can.inc"
#declare r_cans=seed(9267);
union{
 object{lata rotate 360*rand(r_cans)*y translate <0,0,0>}
 object{lata rotate 360*rand(r_cans)*y translate <-diam_lata,0,0>}
 object{lata rotate 360*rand(r_cans)*y translate <-diam_lata*2,0,0>}
 object{lata rotate 360*rand(r_cans)*y translate <-diam_lata*3,0,0>}
 object{lata rotate 360*rand(r_cans)*y translate <0,0,-diam_lata>}
 object{lata rotate 360*rand(r_cans)*y translate <-diam_lata,0,-diam_lata>}
 object{lata rotate 360*rand(r_cans)*y translate <-diam_lata*2,0,-diam_lata>}
 object{lata rotate 360*rand(r_cans)*y translate <-diam_lata*3,0,-diam_lata>}
 rotate 4*y
 translate <room_width*.5-rad_lata-4,91.51,-84>
 translate floor_height*y
}


// *** DAYLIGHT ***
#if (use_daylight)
#declare dll=100;
#if (use_radiosity=2)
light_source{0
 Light_Color(Daylight(7500),dll)
 spotlight radius 90 falloff -91 point_at -x
 Light_Fading()
 translate <room_width*.5+wall_width*.8,win_pos.y,win_pos.z>
 translate floor_height*y
}
#else
#declare glass_light=
union{
  box{-.5,.5 hollow no_shadow
   pigment{rgbt 1} finish{diffuse 0 ambient 0}
   interior{
    media{emission 100}
   }
   scale <33,.1,25>
  }
  light_source{0
    Light_Color(Daylight(7500),dll/4)
    spotlight radius 90 falloff -91 point_at -y
    #if (use_area)
    area_light 32*2*x,25*2*z,8*use_area,6*use_area jitter adaptive 1 orient 
    #end
    Light_Fading()
  }
  rotate -90*z
}
union{
 object{glass_light
  translate <0,win_height*.21,win_width*.21>
 }
 object{glass_light
  translate <0,win_height*.21,-win_width*.21>
 }
 object{glass_light
  translate <0,-win_height*.21,win_width*.21>
 }
 object{glass_light
  translate <0,-win_height*.21,-win_width*.21>
 }
 translate <room_width*.5+wall_width*.8,win_pos.y,win_pos.z>
 translate floor_height*y
}
#end
#end


// *** CAMERA ***
#switch (camera_select)
 #case (1) // final
  #declare cl=<-room_width*.5+10,120,-room_length*.5+5>;
  #declare la=<room_width*.5,110,win_pos.z+30>;
  #declare cd=3.5*z;
  #break
 #case (2) // general right view
  #declare cl=<-23,165,-room_length*.5+5>;
  #declare la=<room_width*.5-50,130,win_pos.z>;
  #declare cd=3.5*z;
  #break
 #case (3) // general left view
  #declare cl=<23,165,-room_length*.5+5>;
  #declare la=<-room_width*.5+50,130,win_pos.z>;
  #declare cd=3.5*z;
  #break
 #case (4) // general front view
  #declare cl=<-1,155,-room_length*.5+5>;
  #declare la=<1,130,win_pos.z>;
  #declare cd=2.8*z;
  #break
 #case (5) // to the furniture
  #declare cl=<-100,65,win_pos.z>;
  #declare la=<100,55,win_pos.z>;
  #declare cd=3.0*z;
  #break
 #case (6) // to the furniture
  #declare cl=<-150,165,win_pos.z-100>;
  #declare la=<100,155,win_pos.z-100>;
  #declare cd=2.8*z;
  #break
 #case (7) // to the furniture
  #declare cl=<130,155,win_pos.z-100>;
  #declare la=<-100,145,win_pos.z-100>;
  #declare cd=2.0*z;
  #break
 #case (8) // to the kitchen
  #declare cl=<-1,115,10>;
  #declare la=<1,90,room_length*.5-30>;
  #declare cd=3.0*z;
  #break
 #case (9) // from the corridor
  #declare cl=<-1,65,-900>;
  #declare la=<1,55,room_length*.5>;
  #declare cd=8.5*z;
  #break
 #case (99) // zenith
  #declare cl=<0,500,-.1>;
  #declare la=<0,0,0>;
  #declare cd=2.8*z;
  #break
#end
#if (camera_select=0)
camera{
 spherical
 location <0,125,0>
 up y*1
 right x*2
 direction 1*z
 look_at  <0,125,1>
 translate floor_height*y
}
#else
camera{
 location cl+floor_height*y
 up y*2.4
 right x*3.6
 direction cd
 look_at la+floor_height*y
 #if (use_blur)
 focal_point la aperture .001 blur_samples use_blur
 #end
 #if (camera_select=99)
  rotate 90*y
 #end
 }
#end

